#
# GPT RPM SPEC file
#
# 2002 - Anders Waananen <waananen@nbi.dk>
#

%define gpt_location /opt/gpt

Summary: The Grid Packaging Toolkit (GPT)
Name: gpt
Version: 3.2
Release: 5ng%{?dist}
URL: http://www.gridpackagingtools.org/
Source: ftp://ftp.ncsa.uiuc.edu/aces/gpt/releases/%{name}-%{version}/%{name}-%{version}-src.tar.gz
Patch0: gpt_globus395.patch
Patch1: globus_package_dtd.patch
Patch2: gpt_setupdir.patch
License: NCSA Software License
Group: System Environment/Base
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Prefix: /etc/profile.d
Prefix: %{gpt_location}
BuildRequires: perl(ExtUtils::MakeMaker)

%description
GPT is a collection of packaging tools built around an XML based
packaging data format. This format provides a straight forward way to
define complex dependency and compatibility relationships between
packages. The tools provide a means for developers to easily define the
packaging data and include it as part of their source code distribution.
Binary packages can be automatically generated from this data. The
packages defined by GPT are compatible with other packages and can be
easily be converted.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
export GPT_LOCATION=$RPM_BUILD_ROOT%{gpt_location}
# The following line fixes an issue with Mandrake 9.2 perl installations
unset RPM_BUILD_ROOT
./build_gpt

%install
#
# Create profile scripts
#
mkdir -p $RPM_BUILD_ROOT/etc/profile.d

# /etc/profile.d/gpt.sh
cat << EOF > $RPM_BUILD_ROOT/etc/profile.d/gpt.sh
if test -f /etc/sysconfig/gpt ; then
  . /etc/sysconfig/gpt
fi
GPT_LOCATION=\${GPT_LOCATION:-%{gpt_location}}
PATH=\${PATH}:\$GPT_LOCATION/sbin
export GPT_LOCATION PATH
EOF
chmod 755 $RPM_BUILD_ROOT/etc/profile.d/gpt.sh

# /etc/profile.d/gpt.csh
cat << EOF > $RPM_BUILD_ROOT/etc/profile.d/gpt.csh
if ( -r /etc/sysconfig/gpt ) then
  eval \`cat /etc/sysconfig/gpt | grep -v ^# | grep = | sed 's/^/set /'\` 
endif

if (! \$?GPT_LOCATION ) then
  set GPT_LOCATION=%{gpt_location}
endif

setenv GPT_LOCATION \${GPT_LOCATION}
setenv PATH \${PATH}:\$GPT_LOCATION/sbin
EOF
chmod 755 $RPM_BUILD_ROOT/etc/profile.d/gpt.csh

#
# Remove .packlist and perllocal.pod files
#
find $RPM_BUILD_ROOT%{gpt_location} \( -name .packlist -o -name perllocal.pod \) -exec rm -f '{}' \;

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if test "x$RPM_INSTALL_PREFIX1" = "x" ; then
  RPM_INSTALL_PREFIX1=/opt/globus
fi

for i in globus_aclocal gpt_amdir; do
  test -d $RPM_INSTALL_PREFIX1/share/$i && rm -fr $RPM_INSTALL_PREFIX1/share/$i
done
exit 0

%files
%defattr(-,root,root)
/etc/profile.d/gpt.sh
/etc/profile.d/gpt.csh
%{gpt_location}

%changelog
* Tue Jun 19 2007 Anders Waananan <waananen@nbi.dk> - 3.2-5ng
- Add dist tag to release
- Change BuildRoot
* Wed Jun  1 2005 Anders Waananan <waananen@nbi.dk> - 3.2-4ng
- Add fix to setup dir handling
- Restructure changelog to have versions on main line
* Fri Mar 18 2005 Anders Waananan <waananen@nbi.dk> - 3.2-3ng
- Add patch to fix globus_package.dtd
* Tue Mar  1 2005 Anders Waananan <waananen@nbi.dk> - 3.2-2ng
- Add patch with fixes from the Globus 3.9.5 GPT release
  (Do not include the core though)
* Fri May 21 2004 Anders Waananen <waananen@nbi.dk> - 3.2-1ng
* Sun Feb  1 2004 Anders Waananen <waananen@nbi.dk> - 3.1-3ng
- Fix problem when new files are links rather than directories
* Thu Jan  8 2004 Anders Waananen <waananen@nbi.dk> - 3.1-2ng
- Fix for Mandrake 9.2 - unset RPM_BUILD_ROOT before building
  Found by Jakob Langgaard Nielsen <langgard@nbi.dk>
* Sat Jan  3 2004 Anders Waananen <waananen@nbi.dk> - 3.1-1ng
- Drop patches:
    gpt-3.0.1-dependency.patch
    gpt-3.0.1-doc.patch
  since the problems involved are either solved or obsolete
- Make /etc/profile.d relocatable
- Use gpt_location macro to define GPT_LOCATION
- Use RPM Group "System Environment/Base" instead of Applications
- Slightly change build procedure
* Tue Oct  7 2003 Anders Waananen <waananen@nbi.dk> - 3.0.1-1ng
- Remove the now unecessary dependency cleanup introduced in 2.2.10-2ng
- Fix some cases in the documentation
* Tue Jun 24 2003 Anders Waananen <waananen@nbi.dk> - 2.2.10-2ng
- Dependency cleanup by Mattias Ellert <mattias.ellert@tsl.uu.se>
* Mon Jun 23 2003 Anders Waananen <waananen@nbi.dk> - 2.2.10
* Sat Jun  2 2003 Anders Waananen <waananen@nbi.dk> - 3.1a1-2
- Fix perl inconsistencies reported by Mattias Ellert <mattias.ellert@tsl.uu.se>
* Sat May 24 2003 Anders Waananen <waananen@nbi.dk> - 3.1a1
- Bring back perl-Tk dependency
* Mon Apr  7 2003 Anders Waananen <waananen@nbi.dk> - 3.0-1ng
* Tue Mar 22 2003 Anders Waananen <waananen@nbi.dk> - 2.2.9-1ng
- Add bogus perl(Grid::GPT::Version) provides to help rpm
* Tue Mar  4 2003 Anders Waananen <waananen@nbi.dk> - 2.2.8-1ng
* Tue Dec  5 2002 Anders Waananen <waananen@nbi.dk> - 2.2.7-1ng
* Tue Nov  5 2002 Anders Waananen <waananen@nbi.dk> - 2.2.5-1ng
- Remove Tk dependence for RedHat 8.0
* Tue Oct 29 2002 Anders Waananen <waananen@nbi.dk> - 2.2.4-2ng
  Insert missing backslash in csh profile script
* Tue Sep 24 2002 Anders Waananen <waananen@nbi.dk>
- Use 2.2 final
* Sat Aug 31 2002 Anders Waananen <waananen@nbi.dk>
- Use 2.2rc1 tarball from Globus CVS
* Thu Aug 15 2002 Anders Waananen <waananen@nbi.dk>
- Use NCSA distribution instead of Globus
* Mon Apr  8 2002 Anders Waananen <waananen@nbi.dk>
- Initial build.
